Module: Recurable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/recurable.rb,
lib/recurable/version.rb
Overview
A concern to be included by ActiveRecord models that persist an rrule string to the database. This concern gives them access to a Recurrence object (instead of an rrule string) which encapsulates user-friendly getters and setters for the rrule, as well as validation, display, and projection concerns.
Constant Summary collapse
- VERSION =
'1.1.0'