Module: Recurable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/recurable.rb,
lib/recurable/version.rb
Overview
setters for the rrule, as well as validation, display, and projection concerns.
Constant Summary collapse
- VERSION =
'1.1.0'
setters for the rrule, as well as validation, display, and projection concerns.
'1.1.0'